Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: src/gpu/GrGpu.h

Issue 2468653002: Remove GrStencilSettings from GrPipeline (Closed)
Patch Set: Remove GrStencilSettings from GrPipeline Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/gpu/GrGpu.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrGpu.h
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h
index 48005ec16f4a675b6f7e06b77c4bc13f6566ceff..475950a4d3ea279ae0dc5c2e0c3155279e767a2a 100644
--- a/src/gpu/GrGpu.h
+++ b/src/gpu/GrGpu.h
@@ -355,10 +355,10 @@ public:
const SkPoint* fSampleLocations;
};
// Finds a render target's multisample specs. The stencil settings are only needed in case we
// need to flush the draw state prior to querying multisample info. They are not expected to
// affect the multisample information itself.
- const MultisampleSpecs& queryMultisampleSpecs(GrRenderTarget*, const GrStencilSettings&);
+ const MultisampleSpecs& queryMultisampleSpecs(const GrPipeline&);
// Finds the multisample specs with a given unique id.
const MultisampleSpecs& getMultisampleSpecs(uint8_t uniqueID) {
« no previous file with comments | « no previous file | src/gpu/GrGpu.cpp » ('j') | no next file with comments »
@@ -355,10 +355,10 @@ public:
const SkPoint* fSampleLocations;
};
- // Finds a render target's multisample specs. The stencil settings are only needed in case we
- // need to flush the draw state prior to querying multisample info. They are not expected to
+ // Finds a render target's multisample specs. The pipeline is only needed in case we need to
+ // flush the draw state prior to querying multisample info. The pipeline is not expected to
// affect the multisample information itself.

Powered by Google App Engine
This is Rietveld 408576698